@@ -1,6 +1,6 @@
-__version__ = "0.3.0"
+__version__ = "0.3.2"
 
 from .entity import BaseEntity
-from .filter import Attribute
+from .filter import Attribute, Filter
 from .sqlalchemy import SQLAlchemyVisitor
 from .visitor import BaseVisitor
